@@ -12,7 +12,9 @@ from .sets import (
     load_tankesse, 
     load_boundiali,
     load_hlogs,
+    load_nlogs, 
     load_huayuan,
+    load_mxs, 
     fetch_data,
     load_edis,
     make_erp , 
@@ -28,7 +30,9 @@ __all__=[
          "load_tankesse", 
          "load_boundiali",
          "load_hlogs",
-         "load_huayuan", 
+         "load_nlogs", 
+         "load_huayuan",
+         "load_mxs", 
          "fetch_data",
          "load_edis",
          "make_erp" , 
