@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Licence:BSD 3-Clause
+#   License: BSD-3-Clause
 #   Author: LKouadio <etanoyau@gmail.com>
 """
 Scikit-learn external 
@@ -150,6 +150,7 @@ from sklearn.metrics import (
     roc_curve, 
     silhouette_samples, 
     make_scorer,
+    matthews_corrcoef, 
 )  
 from sklearn.model_selection import ( 
     train_test_split , 
@@ -222,6 +223,7 @@ __all__=[
     'roc_curve',
     'silhouette_samples', 
     'make_scorer',
+    'matthews_corrcoef', 
     'train_test_split' , 
     'validation_curve', 
     'StratifiedShuffleSplit' , 
