@@ -18,7 +18,10 @@ from .geology import (
     Structural, 
     )
 from .drilling import ( 
-    Borehole 
+    Borehole , 
+    DSBorehole, 
+    DSBoreholes, 
+    DSDrill
     )
 from .stratigraphic import  GeoStrataModel
 
@@ -28,5 +31,7 @@ __all__=[
     'Structural', 
     'Borehole', 
     'GeoStrataModel', 
-    
+    'DSBorehole', 
+    'DSBoreholes',
+    'DSDrill'
     ]
\ No newline at end of file
