@@ -819,7 +819,7 @@ class ElectricalMethods (ABC) :
                 MN: float = 20.,
                 arrangement: str  = 'schlumberger', 
                 area : str = None, 
-                projection: str ='UTM', 
+                projection: str ='lonlat', 
                 datum: str ='WGS84', 
                 epsg: int =None, 
                 utm_zone: str = None,  
@@ -1124,6 +1124,7 @@ class P:
         """
             
         dict_ = self.idictcpr if kind =='ves' else self.idicttags
+        
         for k, val in dict_.items(): 
             for s in val : 
                 if str(it).lower().find(s)>=0: 
@@ -1165,7 +1166,11 @@ class P:
             if hasattr(self.hl, '__iter__'):
                 for item in self.hl : 
                     v_.append( self._check_header_item(item, kind)) 
-                v_=list(filter((None).__ne__, v_))
+                # uncomment this for deprecating warning. Henceforth we use 
+                # lamba instead 
+                # v_=list(filter((None).__ne__, v_))
+                v_ = list(filter(lambda item: item is not None, v_))
+            
                 return None if len (v_) ==0 else v_
             
     @property 
@@ -1244,8 +1249,15 @@ class P:
         """ cpr stands for current-potentials and resistivity. They compose the
         main property values when collected the vertical electrical sounding 
         data."""
+        # return {f'{k.replace("_", "")}': v  for k , v in {
+        #     **self.ves_props, **{'resistivity': self.iresistivity}}.items()}
         return {f'{k.replace("_", "")}': v  for k , v in {
-            **self.ves_props, **{'resistivity': self.iresistivity}}.items()}
+            **self.ves_props, **{'resistivity': self.iresistivity, 
+                                 'longitude': self.ilon, 
+                                 'latitude': self.ilat, 
+                                 'easting': self.ieasting, 
+                                 'northing': self.inorthing }}.items()
+            }
                 
 
 class BagoueNotes: 
@@ -1351,7 +1363,6 @@ class BagoueNotes:
         key:val  for key, val in zip(bagkeys, bagvalues)
                     }
 
-
 class Config: 
     
     """ Container of property elements. 
@@ -1399,9 +1410,33 @@ class Config:
                  ".fwf" : pd.read_fwf, 
                  ".pkl" : pd.read_pickle, 
                  ".sas" : pd.read_sas, 
-                 ".spss": pd.read_spss, 
+                 ".spss": pd.read_spss,
+                 # ".orc" : pd.read_orc, 
                  }
         
+    @staticmethod
+    def writers (object): 
+        """ Write frame formats."""
+        return {".csv"    : object.to_csv, 
+                ".hdf"    : object.to_hdf, 
+                ".sql"    : object.to_sql, 
+                ".dict"   : object.to_dict, 
+                ".xlsx"   : object.to_excel, 
+                ".json"   : object.to_json, 
+                ".html"   : object.to_html , 
+                ".feather": object.to_feather, 
+                ".tex"    : object.to_latex, 
+                ".stata"  : object.to_stata, 
+                ".gbq"    : object.to_gbq, 
+                ".rec"    : object.to_records, 
+                ".str"    : object.to_string, 
+                ".clip"   : object.to_clipboard, 
+                ".md"     : object.to_markdown, 
+                ".parq"   : object.to_parquet, 
+                # ".orc"    : object.to_orc, 
+                ".pkl"    : object.to_pickle 
+                }
+    
     @staticmethod 
     def arrangement(a: int | str ): 
         """ Assert whether the given arrangement is correct. 
@@ -1424,21 +1459,21 @@ class Config:
     def geo_rocks_properties(self ):
         """ Get some sample of the geological rocks. """
         return {
-             "basement rocks" :            [1e99,1e6 ],
-             "igneous rocks":              [1e6, 1e3], 
+             "hard rock" :            [1e99,1e6 ],
+             "igneous rock":              [1e6, 1e3], 
              "duricrust"   :               [5.1e3 , 5.1e2],
              "gravel/sand" :               [1e4  , 7.943e0],
              "conglomerate"    :           [1e4  , 8.913e1],
              "dolomite/limestone" :        [1e5 ,  1e3],
             "permafrost"  :                [1e5  , 4.169e2],
-             "metamorphic rocks" :         [5.1e2 , 1e1],
+             "metamorphic rock" :         [5.1e2 , 1e1],
              "tills"  :                    [8.1e2 , 8.512e1],
              "standstone conglomerate" :   [1e4 , 8.318e1],
              "lignite/coal":               [7.762e2 , 1e1],
              "shale"   :                   [5.012e1 , 3.20e1],
              "clay"   :                    [1e2 ,  5.012e1],
              "saprolite" :                 [6.310e2 , 3.020e1],
-             "sedimentary rocks":          [1e4 , 1e0],
+             "sedimentary rock":          [1e4 , 1e0],
              "fresh water"  :              [3.1e2 ,1e0],
              "salt water"   :              [1e0 , 1.41e0],
              "massive sulphide" :          [1e0   ,  1e-2],
@@ -1461,22 +1496,24 @@ class Config:
         
         The following symbols can be used to create a matplotlib pattern. 
         
-        make _pattern:{'/', '\', '|', '-', '+', 'x', 'o', 'O', '.', '*'}
-                       
-            /   - diagonal hatching
-            \   - back diagonal
-            |   - vertical
-            -   - horizontal
-            +   - crossed
-            x   - crossed diagonal
-            o   - small circle
-            O   - large circle
-            .   - dots
-            *   - stars
+        .. code-block:: none
+        
+            make _pattern:{'/', '\\', '|', '-', '+', 'x', 'o', 'O', '.', '*'}
+                           
+                /   - diagonal hatching
+                \\   - back diagonal
+                |   - vertical
+                -   - horizontal
+                +   - crossed
+                x   - crossed diagonal
+                o   - small circle
+                O   - large circle
+                .   - dots
+                *   - stars
         """
         return  {
-             "basement rocks" :      ['.+++++.', (.25, .5, .5)],
-             "igneous rocks":        ['.o.o.', (1., 1., 1.)], 
+             "hard rock" :      ['.+++++.', (.25, .5, .5)],
+             "igneous rock":        ['.o.o.', (1., 1., 1.)], 
              "duricrust"   :         ['+.+',(1., .2, .36)],
              "gravel" :              ['oO',(.75,.86,.12)],
              "sand":                 ['....',(.23, .36, .45)],
@@ -1484,7 +1521,7 @@ class Config:
              "dolomite" :            ['.-.', (0., .75, .23)],
              "limestone" :           ['//.',(.52, .23, .125)],
             "permafrost"  :          ['o.', (.2, .26, .75)],
-             "metamorphic rocks" :   ['*o.', (.2, .2, .3)],
+             "metamorphic rock" :   ['*o.', (.2, .2, .3)],
              "tills"  :              ['-.', (.7, .6, .9)],
              "standstone ":          ['..', (.5, .6, .9)],
              "lignite coal":         ['+/.',(.5, .5, .4)],
@@ -1492,7 +1529,7 @@ class Config:
              "shale"   :             ['=', (0., 0., 0.7)],
              "clay"   :              ['=.',(.9, .8, 0.8)],
              "saprolite" :           ['*/',(.3, 1.2, .4)],
-             "sedimentary rocks":    ['...',(.25, 0., .25)],
+             "sedimentary rock":    ['...',(.25, 0., .25)],
              "fresh water"  :        ['.-.',(0., 1.,.2)],
              "salt water"   :        ['o.-',(.2, 1., .2)],
              "massive sulphide" :    ['.+O',(1.,.5, .5 )],
@@ -1502,7 +1539,6 @@ class Config:
              
              }
     
-
 class References:
     """
     References information for a citation.
