@@ -5,6 +5,8 @@
 Manage site data.
 """
 from __future__ import annotations 
+import os
+import shutil
 import copy 
 import re
 
@@ -36,6 +38,7 @@ from .utils.funcutils import (
     _validate_name_in, 
     interpolate_grid,
     reshape,
+    is_iterable
     ) 
 from .utils.gistools import (
     assert_elevation_value, 
@@ -43,7 +46,7 @@ from .utils.gistools import (
     assert_lon_value , 
     ll_to_utm, 
     utm_to_ll, 
-    project_points_ll2utm, 
+    project_point_ll2utm, 
     project_point_utm2ll,
     assert_xy_coordinate_system,
     convert_position_str2float, 
@@ -113,7 +116,7 @@ class Profile:
            Object of Profile. 
            
         Note 
-        -------
+        ------
         When `data` is supplied and `x` and `y` are given by their names 
         existing in the dataframe columns, by default, the non-numerical 
         data are removed. However, if `y` and `x` are given in DD:MM:SS in 
@@ -121,6 +124,7 @@ class Profile:
         to keep the non-numerical values  in the data. 
         
         """
+        
         emsg =("'DD:MM:SS.ms' coordinate system is detected.")
         data = fit_params.pop('data', None) 
   
@@ -145,14 +149,26 @@ class Profile:
             if isinstance (elev , str): 
                 elev = elev if elev in data.columns else None 
                 if elev is None: 
-                    warnings.warn(
-                        f"Elevation {elev!r} not found in the dataframe")
+                    warnings.warn("Elevation not found in the dataframe")
                 if elev is not None: 
                     elev = np.array (data[elev]) 
         
         self.x, self.y = assert_xy_in( x , y, data = data )
         
-       
+        # set x and y names useful for 
+        # plotting labels. 
+        self.xname_=None ; self.yname_=None 
+        if ( 
+                isinstance ( x, str ) 
+                or hasattr (x, "name" )
+                ) : 
+            self.xname_= x if isinstance ( x, str ) else x.name 
+        if ( 
+                isinstance ( y, str ) 
+                or hasattr (y, "name" )
+                ) : 
+           self.yname_= y if isinstance ( y, str ) else y.name 
+        
         if self.coordinate_system in ('none', 'auto'): 
             self.coordinate_system = assert_xy_coordinate_system (
                 self.x, self.y )
@@ -161,7 +177,7 @@ class Profile:
             try : 
                 self.x, self.y = Profile.dms2ll(self.x, self.y) 
             except ValueError as e: 
-                raise ( emsg + str(e))
+                raise ValueError( emsg + str(e))
             else: 
                 # initialize the system to ll if 
                 # conversion succeeded. 
@@ -175,12 +191,11 @@ class Profile:
                                         error ='ignore'  ): 
             raise ProfileError ("Elevation and x or y must be consistent."
                               f" Got {len(x)} and {len(elev)}") 
-
         return self 
         
     def bearing (self, *, to_degree:bool = True ): 
         """
-        Compute the bearing between calculate bearing between two coordinates.
+        Compute the bearing between two coordinates.
         
         A bearing is a direction of one point relative to another point, 
         usually given as an angle measured clockwise from north. 
@@ -255,20 +270,18 @@ class Profile:
         -----------
         average_distance: bool, default =True, 
            Returns the average value of the distance between different points. 
-           
-        is_latlon: bool, default=False, 
-            Convert `x` and `y` latitude  and longitude coordinates values 
-            into UTM before computing the distance. `x`, `y` should be considered 
-            as ``easting`` and ``northing`` respectively. 
-            
-        kws: dict, 
-           Keyword arguments passed to :meth:`watex.exmath.get_distance`
-           
+
         Returns 
         ---------
         d: Arraylike of shape (N-1) 
           Is the distance between points or the average of all distances.  
         
+        See Also 
+        ---------
+        watex.utils.exmath.get_distance: 
+            Get the distance from longitude/latitude or easting/northing 
+            coordinates. 
+            
         Examples 
         --------- 
         >>> import numpy as np 
@@ -307,6 +320,7 @@ class Profile:
         -----------
         sp_kws: dict 
            Keyword arguments passed to :func:`~watex.utils.scalePosition`. 
+           
         Returns 
         --------
         x, y : Arraylikes 
@@ -465,7 +479,7 @@ class Profile:
         return map ( lambda i: f(i) , ar)
     
     @staticmethod 
-    def dms2ll (x:ArrayLike  , y:ArrayLike ): 
+    def dms2ll (x:ArrayLike|str  , y:ArrayLike|str , *,  data=None): 
         """ Convert array x and y from DD:MM:SS to degree decimal -longitude 
         (x) and latitude (y). 
         
@@ -475,19 +489,34 @@ class Profile:
            positions.
         Returns 
         --------
-        x, y: Arraylike 
+        x, y: Arraylike or str
            ArrayLike in degree decimal coordinates format. By default `x` and 
            `y` are longitude and latitude respectively. 
+           If `x` and `y` has a string argument, data must be provided, 
+           otherwise an error raises. 
            
-        Examples
+        data: pd.DataFrame 
+          DataFrame containg the position x and y. 
+          
+          .. versionadded:: 0.2.5 
+          
+        Example
         ---------
-        >>> 
         >>> from watex.site import Profile 
         >>> x=['20:15:35'] ; y =['7:45:8.5'] 
         >>> Profile.dms2ll (x, y)
         Out[83]: (array([20.25972222]), array([7.75236111]))
         """
- 
+        if ( 
+                (isinstance (x, str) 
+                or isinstance (y, str)) 
+                and data is None
+                ): 
+            raise TypeError(
+                "Data can't be None when x or y has a string argument.")
+        if data is not None: 
+            x, y = assert_xy_in(x, y, data=data )
+            
         if not _is_numeric_dtype(x , to_array =True ): 
            # reconvert object to str for consistency  
            x = np.array ( list ( Profile.f_(x)), dtype = np.float64 )
@@ -497,22 +526,29 @@ class Profile:
         return x, y
     
     @staticmethod 
-    def ll2dms (x:ArrayLike  , y:ArrayLike ): 
+    def ll2dms (x:ArrayLike|str  , y:ArrayLike|str , *, data=None ): 
         """
         Convert array x and y from degree decimal  to 
         degree-minutes-seconds (DMS)
         
         Parameters 
         -----------
-        x, y: ArrayLike containing the degree decimal position 
-           coordinates. 
+        x, y: ArrayLike or str 
+           Arrays containing the degree decimal position coordinates.
+           If `x` and `y` has a string argument, data must be provided,
+           otherwise an error raises
         
         Returns 
         --------
         x, y: Arraylike 
            ArrayLike in DD:MM:SS coordinates format.
-           
-        Examples
+          
+        data: pd.DataFrame 
+          DataFrame containg the position x and y.
+          
+          .. versionadded:: 0.2.5
+          
+        Example
         ---------
         >>> from watex.site import Profile 
         >>> x =[15.18 ] ; y =[19.60]
@@ -520,6 +556,14 @@ class Profile:
         Out[84]: (array(['15:10:48.00'], dtype='<U11'), 
                   array(['19:36:00.00'], dtype='<U11'))
         """
+        if ( (isinstance (x, str) 
+              or isinstance (y, str)) 
+              and data is None): 
+            raise TypeError(
+                "Data can't be None when x or y has a string argument.")
+            
+        if data is not None: 
+            x, y = assert_xy_in(x, y, data=data )
         if _is_numeric_dtype(x , to_array =True ):  
            x = np.array ( list (Profile.f_ (x, 'll->dms')), dtype = str )
         if _is_numeric_dtype(y , to_array =True): 
@@ -550,12 +594,8 @@ class Profile:
         r: float or int 
             The rotate angle in degrees. Rotate the angle features 
             toward the direction of the projection profile. 
-            Default value use the :meth:`~.bearing` value in degrees.   
-            
-        utm_zone: string (##N or ##S)
-            utm zone in the form of number and North or South hemisphere, 
-            10S or 03N  Must be given if coordinate system is ``UTM``. 
-                          
+            Default value use the :meth:`~.bearing` value in degrees. 
+               
         todms: bool, Default=False
             Reconvert the longitude/latitude degree decimal values into 
             the DD:MM:SS. 
@@ -570,15 +610,27 @@ class Profile:
           
         See Also 
         --------
-        watex.utils.exmath: 
-            Create mutiple coordinates with different kinds 
+        watex.utils.coreutils.makeCoords: 
+            Create mutiple coordinates with different strategies using 
+            references latitude and longitude. 
             
         Examples 
         ----------
-        >>> from watex.utils.coreutils import makeCoords 
-        >>> rlons, rlats = makeCoords('110:29:09.00', '26:03:05.00', 
-        ...                                     nsites = 7, todms=True)
-        
+        >>> import watex as wx 
+        >>> # get two coordinates from random stations
+        >>> data = wx.make_erp (n_stations =2 ).frame 
+        >>> p = Profile ().fit(data.longitude, data.latitude)
+        >>> longs, lats = p.make_xy_coordinates(step =100 , todms =True )
+        >>> longs
+        Out[40]: array(['-99:13:48.11', '-99:13:48.11'], dtype='<U12')
+        >>> lats
+        array(['-85:31:37.57', '-85:31:37.57'], dtype='<U12')
+        >>> p = Profile ().fit(data.easting, data.northing)
+        >>> longs, lats = p.make_xy_coordinates(step =100 , todms =True )
+        >>> longs, lats
+        Out[43]: 
+        (array(['110:58:55.00', '110:58:55.00'], dtype='<U12'),
+         array(['4:32:10.96', '4:32:10.96'], dtype='<U10'))
         """
         def _auto ( v): 
             if str (v).lower().strip() in ('none', 'auto'): 
@@ -594,6 +646,8 @@ class Profile:
         reflong = (self.x[0], self.x[-1])
   
         isutm = False if self.coordinate_system =='ll' else True 
+        utm_zone =  kws.pop ('utm_zone', None ) or self.utm_zone 
+        
         return makeCoords(
             reflong, 
             reflat, 
@@ -601,10 +655,13 @@ class Profile:
             r= r ,  
             step =step , 
             todms=todms, 
-            utm_zone= self.utm_zone, 
+            utm_zone= utm_zone, 
             is_utm= isutm, 
+            datum=self.datum, 
+            espg=self.epsg,
             **kws
             ) 
+    
     def interpolate(
         self, 
         method ='linear', 
@@ -614,11 +671,13 @@ class Profile:
         """
         Interpolate x, y and elev ( if applicable).
         
+        
         Parameters 
         -----------
         inplace: bool, default=True 
            Erase existing value of x , y and elev with the interpolated one. 
-           If ``False`` , its return interpolated x, y and elev. 
+           If ``False`` , it returns interpolated x, y and elev and 
+           keep the previous attributes x, y and elev untouchable.
 
         method: bool, default='nearest', 
            Method of interpolation. One of ['nearest'|'linear'|'cubic'] 
@@ -684,6 +743,175 @@ class Profile:
         
         return x, y, elev 
 
+    @staticmethod 
+    def out (
+        x:ArrayLike , 
+        y:ArrayLike, 
+        /, 
+        elev:ArrayLike =None, 
+        filename:str=None, 
+        basename:str=None , 
+        counter:bool= False , 
+        sep:str =None , 
+        savepath:str =None, 
+        extension:str ='.txt', 
+        how:str='py', 
+        verbose:int=0, 
+        ):
+        """Export coordinates data. 
+        
+        File to export should be ['name' | 'x' |'y' |'elev' ]. 
+        
+        Parameters 
+        -----------
+        x: Arraylike 
+           X-coordinate values to export. 
+           
+        y: ArrayLike, 
+          Y -coordinate values to export. 
+          
+        elev: ArrayLike, 
+           Elevation values to export. If not given should be null. 
+           
+        filename: str, 
+           Name of output file. 
+           
+        basename: str, default='Site'
+           Station/site name of each coordinate (x, y)  position. If not given 
+           should be ``site``. 
+           
+        counter: bool, default=False 
+            If ``True``, count the number site and prefix it. For instance of 
+            `42` sites with the ``basename=AMT``, the first counter site 
+            should be ``00_AMT for Python indexing (``how='py'``)
+            
+        sep: str, default =' ' 
+           the separator between site, x, y, elev. 
+           
+        savepath: str, 
+           Output file destination. Default is current directory. 
+           
+        extension: str, default='.txt'
+           The format of output coordinates files. If the `extension` is 
+           suffixed with the `filename`, it should be used instead. 
+           
+        how: str, default='py'
+          Way for counting the site/station. Any other value should starting 
+          counting the site from 1. 
+             
+        verbose:int, default=False 
+           show message to where the file is saved. 
+           
+        .. versionadded:: 0.2.1 
+        
+        
+        Examples 
+        ---------
+        >>> import numpy as np 
+        >>> import watex as wx 
+        >>> data = wx.make_erp (n_stations=24).frame 
+        >>> wx.site.Profile.out (data.easting, data.northing, verbose =True  )
+        >>> elev = np.random.permutation  (len(data.easting)) *100 
+        >>> wx.site.Profile.out (data.easting, data.northing, elev, 
+                                 filename ='coordinates.txt', basename ='AMT-E1', 
+                                 counter =True )
+        """
+       
+        x = np.array( is_iterable(
+            x, exclude_string =True, transform =True )) 
+        y = np.array( is_iterable(y , exclude_string =True, transform =True )) 
+        elev = np.array( is_iterable(elev , exclude_string =True, 
+                                     transform =True )) 
+        
+        _check_consistency_size(x, y )
+        
+        elev = elev if elev is not None else np.repeat([0.], len(x))
+        # for consitency 
+        _check_consistency_size(y, elev )
+        
+        basename = basename or 'Site'
+        basename = str (basename )
+        filename= filename or 'site'
+        filename = str(filename )
+        
+        sep = sep or " "
+        sep = str(sep )
+ 
+        # make site 
+        sites = [(( f"{ii:02}_" if how=='py' else f"{ii+1:02}_") 
+                  if counter else '') + basename 
+                 for ii in range (len(x )) ]
+        writelines =[]
+        #x = x.astype (str) ; y = y.astype (str) ; elev= elev.astype (str)
+        for site, east, north , elev in zip ( sites, x, y, elev ): 
+            writelines.extend(
+                [site + sep + 
+                 f"{east:.3f}"  +sep +  
+                 f"{north:.3f}"+ sep + 
+                 f"{elev:.3f}"  + '\n' ]
+                )
+
+        filename, ex  = os.path.splitext(filename )
+        extension = extension if ex =='' else ex
+        
+        extension ='.'+ extension.replace ('.', '') # for consistency 
+        
+        with open (filename + extension, 'w',encoding='utf8') as df:
+            df.writelines(writelines)
+
+        if savepath : 
+            shutil.move (filename + extension, savepath )
+            
+        if verbose: 
+            print(f"--> File {filename+extension} is successfull written" + 
+                  (f"to {savepath}." if savepath else '.'))
+        
+    
+    def plot (
+        self, 
+        sites: ArrayLike[str]=None , 
+        basename:str ='S', 
+        coerce:bool=True,  
+        **kws): 
+        """Base plot of the profile. 
+        
+        Parameters 
+        -----------
+        
+        sites: str, Arraylike 
+            The name of the sites that fits each position x, y
+ 
+        basename: str, default='S' 
+           the text to prefix the `site` position when the text is not given. 
+        
+        coerce:bool, default=True 
+           Force the plot despite the given sites do not match the number of  
+           positions `x` and `y`. If ``False``, number of positions must be 
+           consistent with x and y, otherwise error raises. 
+           
+        kws: dict, 
+           Additional keyword arguments passed to
+           :func:`~watex.utils.plotutils.plot_text`
+           
+        .. versionadded:: 0.2.1 
+        
+        
+        """
+        from .utils.plotutils import plot_text 
+        
+        self.inspect 
+        
+        return plot_text (
+            self.x, 
+            self.y , 
+            text = sites, 
+            coerce =coerce, 
+            basename=basename,
+            xlabel= self.xname_ or '', 
+            ylabel = self.yname_ or '', 
+            **kws 
+            )
+ 
     @property 
     def inspect (self): 
         """ Inspect object whether is fitted or not"""
@@ -713,7 +941,7 @@ Profile class deals with the positions collected in the survey area.
 
 In principle, there is no exact solution  between longitude/latitude to 
 x/y coordinates. Indeed, there is no isometric map from the sphere to the 
-plane. Indeed, when you convert lon/lat coordinates from the sphere to x/y 
+plane. when you convert lon/lat coordinates from the sphere to x/y 
 coordinates in the plane, we cannot hope that all lengths will be preserved 
 by this operation. Therefore, we have to accept some kind of deformation. 
 For smallish parts of earth's surface, transverse Mercator is quite common.
@@ -731,9 +959,9 @@ utm_zone: Optional, string
 coordinate_system: str, ['utm'|'dms'|'ll'] 
    The coordinate system in which the data points for the profile is collected. 
    If not given, the auto-detection will be triggered and find the  suitable 
-   coordinate system. However, it is recommended to provide for consistency. 
+   coordinate system. However, it is recommended to provide it for consistency. 
    Note that if `x` and `y` are composed of value less than 180 degrees 
-   for longitude and 90 degrees for latitude should be considered as ``ll`` 
+   for longitude and 90 degrees for latitude, it should be considered as  
    longitude-latitude (``ll``) coordinates system. If `x` and `y` are 
    degree-minutes-second (``dms`` or ``dd:mm:ss``) data, they must be 
    specify as coordinate system in order to accept the non-numerical data 
@@ -781,21 +1009,31 @@ class Location (object):
     def __init__(
         self, 
         lat= None, 
-        lon=None, 
+        lon=None,
+        elev=None, 
+        datum='WGS84', 
+        epsg=None,
+        reference_ellipsoid=23,
+        utm_zone=None, 
         **kwds
         ) :
         self._logging = watexlog.get_watex_logger(
             self.__class__.__name__)
         self._lat = lat 
         self._lon = lon 
+        self._utm_zone=utm_zone
+        self._elev=elev
+        
+        self.datum=datum
+        self.epsg=epsg 
+        self.reference_ellipsoid=reference_ellipsoid
         
-        self.datum = kwds.pop('datum', 'WGS84') 
-        self.epsg = kwds.pop('epsg' , None) 
-        self.reference_ellipsoid = kwds.pop('reference_ellipsoid', 23)
-        self._utm_zone =kwds.pop('utm_zone', None) 
-        self._elev = kwds.pop('elev', None)
         self._east= None 
         self._north =None 
+        
+        for key in list(kwds.keys()) : 
+            setattr (self, key, kwds[key])
+            
     @property 
     def utm_zone (self): 
         return self._utm_zone
@@ -903,26 +1141,26 @@ class Location (object):
             
         self.epsg = epsg or self.epsg 
         self.datum = datum  or self.datum 
-        if not self.datum:  
-            self.datum = 'WGS84'
-
+        
         self.reference_ellipsoid = reference_ellipsoid or \
             self.reference_ellipsoid
      
         try : 
-            self.utm_zone, self.east, self.north= ll_to_utm(
-                reference_ellipsoid=self.reference_ellipsoid,
-                lat = self.lat, 
-                lon= self.lon)
-        
-        except :
-            self.east, self.north, self.utm_zone= project_points_ll2utm(
+            self.east, self.north, self.utm_zone= project_point_ll2utm(
                 lat = self.lat ,
                 lon= self.lon,
                 datum = self.datum , 
                 utm_zone = self.utm_zone ,
                 epsg= self.epsg 
                 ) 
+   
+        except :
+
+            self.utm_zone, self.east, self.north= ll_to_utm(
+                reference_ellipsoid=self.reference_ellipsoid,
+                lat = self.lat, 
+                lon= self.lon)
+        
             
         return float(self.east), float(self.north)
     
@@ -933,7 +1171,8 @@ class Location (object):
         north:float= None, 
         utm_zone:str=None, 
         reference_ellipsoid:int=None , 
-        datum:str = None 
+        datum:str = None, 
+        epsg: int= None, 
         ): 
         """
         Project coodinate on longitude latitude once  data are utm at  given
@@ -953,6 +1192,10 @@ class Location (object):
         datum: string, default ='WGS84'
             well known datum ex. WGS84, NAD27, etc.
             
+        epsg: Optional, int
+            epsg number defining projection (see http://spatialreference.org/ref/ for moreinfo)
+            Overrides utm_zone if both are provided    
+            
         reference_ellipsoid: Optional, int 
             reference ellipsoids is derived from Peter H. Dana's website-
             http://www.utexas.edu/depts/grg/gcraft/notes/datum/elist.html
@@ -977,19 +1220,13 @@ class Location (object):
         if utm_zone is not None : 
             self._utm_zone =utm_zone 
             
-        self.datum = 'WGS84'
+        self.epsg = epsg or self.epsg 
         self.datum = datum or self.datum 
+        
         self.reference_ellipsoid = reference_ellipsoid or \
             self.reference_ellipsoid
                           
         try : 
-            self.lat, self.lon  = utm_to_ll(
-                reference_ellipsoid=self.reference_ellipsoid, 
-                northing = self.north , 
-                easting= self.east, 
-                zone= self.utm_zone 
-                                  ) 
-        except : 
             self.lat , self.lon = project_point_utm2ll(
                 easting = self.east,
                 northing= self.north, 
@@ -997,6 +1234,13 @@ class Location (object):
                 datum= self.datum, 
                 epsg= self.epsg 
                 ) 
+        except : 
+             self.lat, self.lon  = utm_to_ll(
+                reference_ellipsoid=self.reference_ellipsoid, 
+                northing = self.north , 
+                easting= self.east, 
+                zone= self.utm_zone 
+                                  ) 
             
         return self.lat, self.lon 
         
@@ -1005,6 +1249,7 @@ class Location (object):
         lats:ArrayLike, 
         lons:ArrayLike, 
         *, 
+        data=None, 
         utm_zone:str =None, 
         datum: str=None, 
         **kws 
@@ -1018,10 +1263,16 @@ class Location (object):
            Array composed of latitude values 
         lons: ArrayLike 1d, 
            Array composed of longitude values. 
- 
+           
+        data: pd.dataFrame
+           Accepts dataframe containing the latitude and longitude coordinates
+           by specifying the columns through 'lats' and 'lons' columns. 
+           
+           .. versionadded:: 0.2.5
+           
         utm_zone: Optional, string
-            zone number and 'S' or 'N' e.g. '55S'. Defaults to the centre point
-            of the provided points, 
+           zone number and 'S' or 'N' e.g. '55S'. Defaults to the centre point
+           of the provided points, 
         datum: string
             well known datum ex. WGS84, NAD27, NAD83, etc.
             
@@ -1042,16 +1293,30 @@ class Location (object):
             coordinates. 
             
         """
+        if ( 
+                (isinstance (lats, str ) 
+                or isinstance ( lons, str) )
+                and data is None): 
+            raise TypeError ("Data can't be None when latitude or longitude"
+                             " has a string argumemt.")
+        if data is not None: 
+            lats, lons = assert_xy_in(lats, lons , data = data )      
         
-        emsg = ("longitude" if lons is None else 'latitude') if (
-            lats is None or lons is None) else "Both longitude and latitude"
+        emsg = ("longitude is " if lons is None else 'latitude is') if (
+            lats is None or lons is None) else "Both longitude and latitude are"
         
         if lats is None or lons is None: 
-            raise TypeError (emsg) 
-            
+            raise TypeError (emsg + "missing.") 
+        # For consistency, check iterable values 
+        
+        lats = is_iterable(lats, exclude_string= True, transform =True ) 
+        lons = is_iterable(lons, exclude_string= True, transform= True )
+        
         _check_consistency_size(lats, lons)
         lats = np.array(lats ) ; lons = np.array (lons )
-        easts = norths = np.zeros_like (lats , dtype = np.float64)
+        easts = np.zeros_like (lats , dtype = np.float64)
+        norths = np.zeros_like (lons , dtype = np.float64)
+        
         for ii, (lat, lon) in enumerate (zip (lats, lons )) : 
             Loc = Location()
             x, y  = Loc.to_utm (lat, lon , utm_zone= utm_zone , **kws )
@@ -1065,7 +1330,8 @@ class Location (object):
         easts:ArrayLike, 
         norths:ArrayLike, 
         *, 
-        utm_zone:str, 
+        data=None,
+        utm_zone:str=None, 
         datum: str=None, 
         **kws 
         ):
@@ -1083,6 +1349,13 @@ class Location (object):
         utm_zone: Optional, string
            zone number and 'S' or 'N' e.g. '55S'. Defaults to the centre point
            of the provided points, 
+           
+        data: pd.dataFrame
+           Accepts dataframe containing the easting and northing coordinates
+           by specifying the columns through 'easts' and 'lats' columns. 
+           
+           .. versionadded:: 0.2.5
+           
         datum: string
            well known datum ex. WGS84, NAD27, NAD83, etc.
             
@@ -1103,13 +1376,26 @@ class Location (object):
            coordinates. 
             
         """
-        
-        emsg = ("easting" if easts is None else 'northing') if (
-            easts is None or norths is None) else "Both easting and northing"
+        if (  ( isinstance (easts, str ) 
+            or isinstance ( norths, str) )
+            and data is None): 
+            raise TypeError ("Data can't be None when easting or northing"
+                             " has a string argumemt.")
+        if data is not None: 
+            easts , norths = assert_xy_in(easts, norths, data = data )
+            
+        emsg = ("easting is" if easts is None else 'northing is') if (
+            easts is None or norths is None) else (
+                "Both easting and northing are")
         
         if easts is None or norths is None: 
-            raise TypeError (emsg) 
+            raise TypeError (emsg + " missing.") 
             
+        # For consistency, check iterable values 
+        easts = is_iterable(easts, exclude_string= True,  transform =True ) 
+        norths = is_iterable(norths, transform= True , exclude_string =True 
+                             )
+        
         _check_consistency_size(easts, norths)
         easts = np.array(easts ) ; norths = np.array (norths )
         lats_lons =[]
