@@ -17,7 +17,7 @@ import numpy as np
 from numpy.core.numeric import ComplexWarning  # type: ignore
 from contextlib import suppress
 import scipy.sparse as sp
-from inspect import signature, Parameter
+from inspect import signature, Parameter, isclass 
 
 from ._array_api import get_namespace, _asarray_with_order
 
@@ -164,6 +164,7 @@ def _assert_z_or_edi_objs ( z_or_edis_obj_list, /):
         
     return obj_type 
        
+
 def assert_xy_in (
     x, 
     y, *, 
@@ -325,6 +326,16 @@ def _check_consistency_size (ar1, ar2 , /  , error ='raise') :
         
     return len(ar1)==len(ar2) 
 
+def check_consistency_size ( *arrays ): 
+    """ Check consistency of array and raises error otherwise."""
+    lengths = [len(X) for X in arrays if X is not None]
+    uniques = np.unique(lengths)
+    if len(uniques) > 1:
+        raise ValueError(
+            "Found input variables with inconsistent numbers of samples: %r"
+            % [int(l) for l in lengths]
+        )
+        
 def _is_buildin (o, /, mode ='soft'): 
     """ Returns 'True' wether the module is a Python buidling function. 
     
@@ -402,7 +413,7 @@ def _validate_ves_operator (
         kept to ``None``.
     ensure_2d: bool, default=False, 
         If ``True`` return array-like of two dimensional where the first and 
-        second cimunns are AB and rhoa respectively. 
+        second columns are AB and rhoa respectively. 
     as_frame: bool, default=False
         If ``True``, returns a pd.dataframe of AB and rhoa columns. 
         
@@ -423,8 +434,8 @@ def _validate_ves_operator (
         if not _is_valid_ves(data): 
             raise exception( 
                 "Wrong VES data. Unable to find [AB|resistivity] in the "
-                " ghiven data. Refer to :class:`~.watex._docstring.ves_doc`"
-                " to see how to construct a proper VES data.")
+                " given data. Refer to :class:`~.watex._docstring.ves_doc`"
+                " to see how to build a proper VES data.")
         rhoa = np.array(data.resistivity )
         AB= np.array(data.AB) 
     
@@ -516,7 +527,7 @@ def _check_array_in(obj, /, arr_name):
     Parameters
     ----------
     obj : object 
-       Object that is expect to contain the array attribute.
+       Object that is expected to contain the array attribute.
     Returns
     -------
     X : array
@@ -1032,7 +1043,77 @@ def _get_feature_names(X):
     if len(types) == 1 and types[0] == "str":
         return feature_names
 
+def check_is_fitted(estimator, attributes=None, *, msg=None, all_or_any=all):
+    """Perform is_fitted validation for estimator.
 
+    Checks if the estimator is fitted by verifying the presence of
+    fitted attributes (ending with a trailing underscore) and otherwise
+    raises a NotFittedError with the given message.
+
+    If an estimator does not set any attributes with a trailing underscore, it
+    can define a ``__sklearn_is_fitted__`` method returning a boolean to specify if the
+    estimator is fitted or not.
+
+    Parameters
+    ----------
+    estimator : estimator instance
+        Estimator instance for which the check is performed.
+
+    attributes : str, list or tuple of str, default=None
+        Attribute name(s) given as string or a list/tuple of strings
+        Eg.: ``["coef_", "estimator_", ...], "coef_"``
+
+        If `None`, `estimator` is considered fitted if there exist an
+        attribute that ends with a underscore and does not start with double
+        underscore.
+
+    msg : str, default=None
+        The default error message is, "This %(name)s instance is not fitted
+        yet. Call 'fit' with appropriate arguments before using this
+        estimator."
+
+        For custom messages if "%(name)s" is present in the message string,
+        it is substituted for the estimator name.
+
+        Eg. : "Estimator, %(name)s, must be fitted before sparsifying".
+
+    all_or_any : callable, {all, any}, default=all
+        Specify whether all or any of the given attributes must exist.
+
+    Raises
+    ------
+    TypeError
+        If the estimator is a class or not an estimator instance
+
+    NotFittedError
+        If the attributes are not found.
+    """
+    from ..exceptions import NotFittedError 
+    if isclass(estimator):
+        raise TypeError("{} is a class, not an instance.".format(estimator))
+    if msg is None:
+        msg = (
+            "This %(name)s instance is not fitted yet. Call 'fit' with "
+            "appropriate arguments before using this estimator."
+        )
+
+    if not hasattr(estimator, "fit"):
+        raise TypeError("%s is not an estimator instance." % (estimator))
+
+    if attributes is not None:
+        if not isinstance(attributes, (list, tuple)):
+            attributes = [attributes]
+        fitted = all_or_any([hasattr(estimator, attr) for attr in attributes])
+    elif hasattr(estimator, "__sklearn_is_fitted__"):
+        fitted = estimator.__sklearn_is_fitted__()
+    else:
+        fitted = [
+            v for v in vars(estimator) if v.endswith("_") and not v.startswith("__")
+        ]
+
+    if not fitted:
+        raise NotFittedError(msg % {"name": type(estimator).__name__})
+        
 def _check_feature_names_in(estimator, input_features=None, *, generate_names=True):
     """Check `input_features` and generate names if needed.
     Commonly used in :term:`get_feature_names_out`.
@@ -1144,7 +1225,7 @@ def _check_estimator_name(estimator):
 
 def set_array_back (X, *,  to_frame=False, columns = None, input_name ='X'): 
     """ Set array back to frame, reconvert the Numpy array to pandas series 
-    or dataframe.
+    or dataframe. 
     
     Parameters 
     ----------
@@ -1203,7 +1284,6 @@ def set_array_back (X, *,  to_frame=False, columns = None, input_name ='X'):
                 columns = columns [0]
                 
             X= pd.Series (X, name =columns )
-            
         else: 
             # columns is str , reconvert to a list 
             # and check whether the columns match 
